@@ -2,7 +2,7 @@
  * interdiff - create incremental patch between two against a common source
  * combinediff - create cumulative patch from two incremental patches
  * flipdiff - exchange the order of two incremental patches
- * Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Tim Waugh <twaugh@redhat.com>
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2009 Tim Waugh <twaugh@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -714,15 +714,15 @@ output_patch1_only (FILE *p1, FILE *out, int not_reverted)
 			oldnamelen = 0;
 		}
 		if (getline (&oldname, &oldnamelen, p1) < 0)
-			error (EXIT_FAILURE, errno, "Bad patch1");
+			error (EXIT_FAILURE, errno, "Bad patch #1");
 
 	} while (strncmp (oldname, "--- ", 4));
 	oldname[strlen (oldname) - 1] = '\0';
 
 	if (getline (&newname, &newnamelen, p1) < 0)
-		error (EXIT_FAILURE, errno, "Bad patch1");
+		error (EXIT_FAILURE, errno, "Bad patch #1");
 	if (strncmp (newname, "+++ ", 4))
-		error (EXIT_FAILURE, errno, "Bad patch1");
+		error (EXIT_FAILURE, errno, "Bad patch #1");
 	newname[strlen (newname) - 1] = '\0';
 	start = ftell (p1);
 
@@ -1019,7 +1019,7 @@ output_delta (FILE *p1, FILE *p2, FILE *out)
 			oldname = NULL;
 		}
 		if (getline (&oldname, &namelen, p1) < 0)
-			error (EXIT_FAILURE, errno, "Bad patch1");
+			error (EXIT_FAILURE, errno, "Bad patch #1");
 
 	} while (strncmp (oldname, "+++ ", 4));
 	oldname[strlen (oldname) - 1] = '\0';
@@ -1087,7 +1087,7 @@ output_delta (FILE *p1, FILE *p2, FILE *out)
 		/* ANOTHER temporary file!  This is to catch the case
 		 * where we just don't have enough context to generate
 		 * a proper interdiff. */
-		FILE *tmpdiff = tmpfile ();
+		FILE *tmpdiff = xtmpfile ();
 		char *line = NULL;
 		size_t linelen;
 		for (;;) {
@@ -1482,7 +1482,7 @@ take_diff (const char *f1, const char *f2, char *headers[2],
 	}
 
 	if (!diff_is_empty) {
-		FILE *tmpdiff = tmpfile ();
+		FILE *tmpdiff = xtmpfile ();
 		while (!feof (in)) {
 			int ch = fgetc (in);
 			if (ch != EOF)
@@ -1821,8 +1821,8 @@ interdiff (FILE *p1, FILE *p2, const char *patch1, const char *patch2)
 	FILE *flip1 = NULL, *flip2 = NULL;
 
 	if (mode == mode_flip) {
-		flip1 = tmpfile ();
-		flip2 = tmpfile ();
+		flip1 = xtmpfile ();
+		flip2 = xtmpfile ();
 	}
 
 	if (index_patch2 (p2))
@@ -1933,15 +1933,24 @@ syntax (int err)
 "usage: %s [OPTIONS] patch1 patch2\n"
 "       %s --version|--help\n"
 "OPTIONS are:\n"
-"  -U N            max lines of context to carry\n"
-"  -i              Consider upper- and lower-case to be the same\n"
-"  -w              ignore whitespace changes in patches\n"
-"  -b              ignore changes in the amount of whitespace\n"
-"  -B              ignore changes whose lines are all blank\n"
-"  -p N            pathname components to ignore\n"
-"  -q              don't add rationale text\n"
-"  -d PAT          drop context on matching files\n"
-"  -z              decompress .gz and .bz2 files\n"
+"  -U N, --unified=N\n"
+"                  max lines of context to carry\n"
+"  -i, --ignore-case\n"
+"                  Consider upper- and lower-case to be the same\n"
+"  -w, --ignore-all-space\n"
+"                  ignore whitespace changes in patches\n"
+"  -b, --ignore-space-change\n"
+"                  ignore changes in the amount of whitespace\n"
+"  -B, --ignore-blank-lines\n"
+"                  ignore changes whose lines are all blank\n"
+"  -p N, --strip-match=N\n"
+"                  pathname components to ignore\n"
+"  -q, --quiet\n"
+"                  don't add rationale text\n"
+"  -d PAT, --drop-context=PAT\n"
+"                  drop context on matching files\n"
+"  -z, --decompress\n"
+"                  decompress .gz and .bz2 files\n"
 "  --interpolate   run as 'interdiff'\n"
 "  --combine       run as 'combinediff'\n"
 "  --flip          run as 'flipdiff'\n"
@@ -2014,6 +2023,15 @@ main (int argc, char *argv[])
 			{"no-revert-omitted", 0, 0, 1000 + 'R' },
 			{"in-place", 0, 0, 1000 + 'i' },
 			{"debug", 0, 0, 1000 + 'D' },
+			{"strip-match", 1, 0, 'p'},
+			{"unified", 1, 0, 'U'},
+			{"drop-context", 1, 0, 'd'},
+			{"ignore-blank-lines", 0, 0, 'B'},
+			{"ignore-space-change", 0, 0, 'b'},
+			{"ignore-case", 0, 0, 'i'},
+			{"ignore-all-space", 0, 0, 'w'},
+			{"decompress", 0, 0, 'z'},
+			{"quiet", 0, 0, 'q'},
 			{0, 0, 0, 0}
 		};
 		char *end;
